export class TablocOptions {
  get(key) {
    return new Promise((resolve) => {
      chrome.storage.local.get([key], (options) => {
        const value = options[key];
        if (value == undefined) {
          resolve(this.getDefault(key));
          return;
        }
        if(value == "false"){
          resolve(false);
          return;
        }
        resolve(value);
        return;
      });
    });
  }

  async getDefault(key) {
    switch (key) {
      case "fg_foreground": return false;
      case "pos_last": return false;
      case "pos_relative": return false;
      case "ex_inpagelink": return true;
      case "ex_formsubmit": return false;
      case "ic_emoji": return "\ud83d\udd12";
      case "ic_enabled": return "locked.png";
      case "ic_disabled": return "tabloc.png";
      case "auto_url_background": {
        const fg_foreground = this.get("fg_foreground");
        const auto_url = this.get("auto_url");
        return (await fg_foreground) ? '': (await auto_url);
      }
      case "auto_url_foreground": {
        const fg_foreground = this.get("fg_foreground");
        const auto_url = this.get("auto_url");
        return (await fg_foreground) ? (await auto_url) : '';
      }
      case "auto_url_exclude": return "";
      case "auto_url": return "";
    }
  }

  set(key, value) {
    chrome.storage.local.set({[key]: value});
  }
}
